==> openshift-model-6.9.0-sources.jar: io/fabric8/openshift/api/model/SourceRevisionFluent.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class SourceRevisionFluent<A extends SourceRevisionFluent<A>> extends BaseFluent<A>{
  public SourceRevisionFluent() {
  }
  
  public SourceRevisionFluent(SourceRevision instance) {
    this.copyInstance(instance);
  }
  private GitSourceRevisionBuilder git;
  private String type;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(SourceRevision instance) {
    instance = (instance != null ? instance : new SourceRevision());
  
    if (instance != null) {
        this.withGit(instance.getGit());
        this.withType(instance.getType());
        this.withGit(instance.getGit());
        this.withType(instance.getType());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public GitSourceRevision buildGit() {
    return this.git!=null ?this.git.build():null;
  }
  
  public A withGit(GitSourceRevision git) {
    _visitables.get("git").remove(this.git);
    if (git!=null){ this.git= new GitSourceRevisionBuilder(git); _visitables.get("git").add(this.git);} else { this.git = null; _visitables.get("git").remove(this.git); } return (A) this;
  }
  
  public boolean hasGit() {
    return this.git != null;
  }
  
  public GitNested<A> withNewGit() {
    return new GitNested(null);
  }
  
  public GitNested<A> withNewGitLike(GitSourceRevision item) {
    return new GitNested(item);
  }
  
  public GitNested<A> editGit() {
    return withNewGitLike(java.util.Optional.ofNullable(buildGit()).orElse(null));
  }
  
  public GitNested<A> editOrNewGit() {
    return withNewGitLike(java.util.Optional.ofNullable(buildGit()).orElse(new GitSourceRevisionBuilder().build()));
  }
  
  public GitNested<A> editOrNewGitLike(GitSourceRevision item) {
    return withNewGitLike(java.util.Optional.ofNullable(buildGit()).orElse(item));
  }
  
  public String getType() {
    return this.type;
  }
  
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  
  public boolean hasType() {
    return this.type != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SourceRevisionFluent that = (SourceRevisionFluent) o;
    if (!java.util.Objects.equals(git, that.git)) return false;
  
    if (!java.util.Objects.equals(type, that.type)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(git,  type,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (git != null) { sb.append("git:"); sb.append(git + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class GitNested<N> extends GitSourceRevisionFluent<GitNested<N>> implements Nested<N>{
    GitNested(GitSourceRevision item) {
      this.builder = new GitSourceRevisionBuilder(this, item);
    }
    GitSourceRevisionBuilder builder;
    
    public N and() {
      return (N) SourceRevisionFluent.this.withGit(builder.build());
    }
    
    public N endGit() {
      return and();
    }
    
  
  }

}

==> openshift-model-6.9.1-sources.jar: io/fabric8/openshift/api/model/SourceRevisionFluent.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class SourceRevisionFluent<A extends SourceRevisionFluent<A>> extends BaseFluent<A>{
  public SourceRevisionFluent() {
  }
  
  public SourceRevisionFluent(SourceRevision instance) {
    this.copyInstance(instance);
  }
  private GitSourceRevisionBuilder git;
  private String type;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(SourceRevision instance) {
    instance = (instance != null ? instance : new SourceRevision());
    if (instance != null) {
          this.withGit(instance.getGit());
          this.withType(instance.getType());
          this.withGit(instance.getGit());
          this.withType(instance.getType());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public GitSourceRevision buildGit() {
    return this.git != null ? this.git.build() : null;
  }
  
  public A withGit(GitSourceRevision git) {
    this._visitables.remove(this.git);
    if (git != null) {
        this.git = new GitSourceRevisionBuilder(git);
        this._visitables.get("git").add(this.git);
    } else {
        this.git = null;
        this._visitables.get("git").remove(this.git);
    }
    return (A) this;
  }
  
  public boolean hasGit() {
    return this.git != null;
  }
  
  public GitNested<A> withNewGit() {
    return new GitNested(null);
  }
  
  public GitNested<A> withNewGitLike(GitSourceRevision item) {
    return new GitNested(item);
  }
  
  public GitNested<A> editGit() {
    return withNewGitLike(java.util.Optional.ofNullable(buildGit()).orElse(null));
  }
  
  public GitNested<A> editOrNewGit() {
    return withNewGitLike(java.util.Optional.ofNullable(buildGit()).orElse(new GitSourceRevisionBuilder().build()));
  }
  
  public GitNested<A> editOrNewGitLike(GitSourceRevision item) {
    return withNewGitLike(java.util.Optional.ofNullable(buildGit()).orElse(item));
  }
  
  public String getType() {
    return this.type;
  }
  
  public A withType(String type) {
    this.type = type;
    return (A) this;
  }
  
  public boolean hasType() {
    return this.type != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SourceRevisionFluent that = (SourceRevisionFluent) o;
    if (!java.util.Objects.equals(git, that.git)) return false;
    if (!java.util.Objects.equals(type, that.type)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(git,  type,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (git != null) { sb.append("git:"); sb.append(git + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class GitNested<N> extends GitSourceRevisionFluent<GitNested<N>> implements Nested<N>{
    GitNested(GitSourceRevision item) {
      this.builder = new GitSourceRevisionBuilder(this, item);
    }
    GitSourceRevisionBuilder builder;
    
    public N and() {
      return (N) SourceRevisionFluent.this.withGit(builder.build());
    }
    
    public N endGit() {
      return and();
    }
    
  
  }

}
